@@ -217,7 +217,7 @@ class Database:
     def set_progress_quantity(self, value):
         self.update_first_loop('progress_quantity', value)
 
-    def get_current_status(self, keys=None):
+    def get_current_status(self, keys=None, with_progress = False):
         """
         Function returning the current status of the simulation.
         """
@@ -245,34 +245,95 @@ class Database:
             pass
 
         if parallel_run:
+            if not with_progress:
+                table = PrettyTable()
+                table.field_names = ["Workflow number", "Status"]
+                # match_val = {"start": "S", "hold": "H", "end": 'F'}
+                # table.add_rows([[key, match_val[value]] if value in match_val
+                #                     else [key, '?'] for key, value in par_dict.items()])
+
+                symbol = {"start": "S", "wait": "W", "end": "F", "error": "E"}
+                table.add_rows([(key, symbol.get(val, '?'))
+                                for key, val in par_dict.items()])
+
+                # keep for now in case we run with no match issue
+                # table.field_names = ["Workflow number", "Status"]
+                # for key, value in par_dict.items():
+                #     val = "?"
+                #     if value == "start":
+                #         val = "S"
+                #     elif value == "hold":
+                #         val = "H"
+                #     elif value == "end":
+                #         val = "F"
+                #     table.add_row([key,val])
+
+                # print("S: Submitted, F: Finished, W: Wait, E: Error")
+                # print(table)
+                status_string.append("S: Submitted, F: Finished, W: Wait, E: Error")
+                status_string.append(table)
+                return status_string
+
+            # case with progress variable
             table = PrettyTable()
-            table.field_names = ["Workflow number", "Status"]
-            # match_val = {"start": "S", "hold": "H", "end": 'F'}
-            # table.add_rows([[key, match_val[value]] if value in match_val
-            #                     else [key, '?'] for key, value in par_dict.items()])
-
+            table.field_names = ["Workflow number", "Status", 'Progress']
             symbol = {"start": "S", "wait": "W", "end": "F", "error": "E"}
-            table.add_rows([(key, symbol.get(val, '?'))
-                            for key, val in par_dict.items()])
-
-            # keep for now in case we run with no match issue
-            # table.field_names = ["Workflow number", "Status"]
-            # for key, value in par_dict.items():
-            #     val = "?"
-            #     if value == "start":
-            #         val = "S"
-            #     elif value == "hold":
-            #         val = "H"
-            #     elif value == "end":
-            #         val = "F"
-            #     table.add_row([key,val])
-
-            # print("S: Submitted, F: Finished, W: Wait, E: Error")
-            # print(table)
+            _string =  [(key, symbol.get(val, '?'), 'NA')
+                                for key, val in par_dict.items()]
+            main_dir = os.getcwd()
+            for ii, keys in enumerate(_string):
+                if keys[1] in ['W']:
+                    break
+                os.chdir(keys[0])
+                tmp_db = Database()
+                try:
+                    progress_var = tmp_db.get_first_loop_val('progress_quantity')
+                except KeyError:
+                    print("NOTE: progress_quantity not defined")
+                    break
+                try:
+                    tmp_progress = tmp_db.get_current_loop_val(progress_var)
+                except KeyError: 
+                    # case when progress var not yet added in current loop
+                    # we will then instead use the previous loop
+                    if tmp_db.get_current_loop_val('loop_count') == 1:
+                        break
+                    tmp_progress = tmp_db.get_previous_loop_val(progress_var)
+                if isinstance(tmp_progress, float):
+                    tmp_progress = np.round(tmp_progress,5)
+                _string[ii] = (_string[ii][0], _string[ii][1], tmp_progress)
+                os.chdir(main_dir)
+            table.add_rows(_string)
             status_string.append("S: Submitted, F: Finished, W: Wait, E: Error")
             status_string.append(table)
             return status_string
 
+
+
+
+        def _handle_first_loop(loop, loop_num, keys):
+            """ Function rendering the lemmings-hpc status in case of a first loop
+                of a chain of a first loop after a --restart
+            """
+            value_list = []
+
+            for key in keys:
+                if key in loop:
+                    if key in ['solut_path']:
+                        tmp_path = loop[key].split('/')[0]
+                        if tmp_path == '.':
+                            tmp_path = './'
+                        value_list.append(tmp_path)
+                    elif key in ['job_id', 'pjob_id']:
+                        value_list.append(loop[key])
+                    else:
+                        value_list.append('Submitted')
+                else:
+                    value_list.append('Submitted')
+            value_list = [str(ii)] + value_list
+            
+            return value_list
+            
         # print()
         # print("Status for chain %s " % (chain_name))
         status_string.append("Status for chain %s " % (chain_name))
@@ -303,34 +364,68 @@ class Database:
 
         end_message = None
 
-        match_cond_reached_keys = {'True': 'ended, finalized', 'False': 'ended, continue', 'None': 'ended, crashed'}
+        match_cond_reached_keys = {'True': 'ended, finalized',
+                                    'False': 'ended, continue',
+                                    'None': 'ended, crashed'}
         table = PrettyTable()
         for ii, loop in enumerate(database[chain_name]):
             value_list = []
 
             # Separate handling of first loop situation
             if self.get_current_loop_val('loop_count') == 1:
-                for key in keys:
-                    if key in loop:
-                        if key in ['solut_path']:
-                            tmp_path = loop[key].split('/')[0]
-                            if tmp_path == '.':
-                                tmp_path = './'
-                            value_list.append(tmp_path)
-                        elif key in ['job_id', 'pjob_id']:
-                            value_list.append(loop[key])
-                        else:
-                            value_list.append('Submitted')
-                    else:
-                        value_list.append('Submitted')
-                value_list = [str(ii)] + value_list
-                table.field_names = ["Loop"] + names_keys
-                table.add_row(value_list)
-                if loop["end_message"] is not None:
-                    end_message = customise_end_message(self, ii, loop["end_message"])
-                break
+                if not 'condition_reached' in loop:
+                    # in case condition_reached is present, we went to post_job already
+                    # then the handling should be the normal one
+                    value_list = _handle_first_loop(loop, ii, keys)
+                    table.field_names = ["Loop"] + names_keys
+                    table.add_row(value_list)
+
+                    if loop["end_message"] is not None:
+                        end_message = customise_end_message(self, ii, loop["end_message"])
+                    break
+
+                if not 'end_cpu_time' in loop:
+                    # case first loop is running
+                    value_list = _handle_first_loop(loop, ii, keys)
+                    table.field_names = ["Loop"] + names_keys
+                    table.add_row(value_list)
+                    break
+
+            if 'restart' in loop:
+                if loop['restart']:
+                    end_message = None # we reinit the end_message as loop restarted
+                    # value_list = ['---']*(len(keys)+1)
+                    # table.add_row(value_list)
+                    value_list = ['restart'] + ['-----']*len(keys)
+                    table.add_row(value_list)
+                    value_list = [] # reinit value_list
+                    if not 'end_cpu_time' in loop:
+                        # for key in keys:
+                        #     if key in loop:
+                        #         if key in ['solut_path']:
+                        #             tmp_path = loop[key].split('/')[0]
+                        #             if tmp_path == '.':
+                        #                 tmp_path = './'
+                        #             value_list.append(tmp_path)
+                        #         elif key in ['job_id', 'pjob_id']:
+                        #             value_list.append(loop[key])
+                        #         else:
+                        #             value_list.append('Submitted')
+                        #     else:
+                        #         value_list.append('Submitted')
+                        # value_list = [str(ii)] + value_list
+                        value_list = _handle_first_loop(loop, ii, keys)
+
+                        table.field_names = ["Loop"] + names_keys
+                        table.add_row(value_list)
+                        if loop["end_message"] is not None:
+                            end_message = customise_end_message(self, ii, loop["end_message"])
+                        break
 
             if not 'solut_path' in loop and not 'job_id' in loop:
+                # JJ: this case won't happen any more I believe
+            # print(self.count, ii)
+            # if ii == self.count:
                 # if 'job_id' in loop:
                 #     continue
                 if loop["end_message"] is not None:
@@ -355,7 +450,7 @@ class Database:
                         else:
                             value_list.append(loop[key])
                     else:
-                        if 'condition_reached' not in loop:
+                        if 'condition_reached' not in loop: # will only be added in post_job part
                             value_list.append('Submitted')
                         elif key in [progress_var]:
                             value_list.append("NA")
@@ -373,8 +468,12 @@ class Database:
                 table.field_names = ["Loop"] + names_keys
                 table.add_row(value_list)
 
-                if loop["end_message"] is not None:
-                    end_message = customise_end_message(self, ii, loop["end_message"])
+                # print(loop["end_message"])
+                try:
+                    if loop["end_message"] is not None:
+                        end_message = customise_end_message(self, ii, loop["end_message"])
+                except KeyError: # case when post_job still has to run and add end_message to database
+                    pass
 
         status_string.append(table)
         if end_message is not None:
@@ -427,15 +526,22 @@ def customise_end_message(database, loop_num, end_msg):
     if not isinstance(loop_num, int):
         loop_num = int(loop_num)
 
-    if not loop_num == 0:
-        end_message = "\n  Latest loop = %1d \n" % (loop_num - 1)
-    else:
-        end_message = "\n  Latest loop = %1d \n" % loop_num
+    # if not loop_num == 0:
+    #     end_message = "\n  Latest loop = %1d \n" % loop_num#(loop_num - 1)
+    # else:
+    #     end_message = "\n  Latest loop = %1d \n" % loop_num
+    end_message = "\n  Latest loop = %1d \n" % loop_num
 
     try:
+        # end_message += ["  Latest job and pjob IDs = "
+        #                 + database.get_loop_val('job_id', (loop_num))
+        #                 + ' and ' + database.get_loop_val('pjob_id', (loop_num))
+        #                 ][0]
+
+        # Starts counting at 1!!
         end_message += ["  Latest job and pjob IDs = "
-                        + database.get_loop_val('job_id', (loop_num))
-                        + ' and ' + database.get_loop_val('pjob_id', (loop_num))
+                        + database.get_loop_val('job_id', (loop_num+1))
+                        + ' and ' + database.get_loop_val('pjob_id', (loop_num+1))
                         ][0]
     except KeyError:
         pass
